Module composition

Module composition 

Re-exports

pub use crate::supergraph::Merged;
pub use crate::supergraph::Satisfiable;
pub use crate::supergraph::Supergraph;

Structs

CompositionOptions
Options that configure composition. Mirrors the JS CompositionOptions interface (see composition-js/src/compose.ts). Most fields are not yet ported — add them here as needed.

Functions

compose
Mirrors the JS compose function.
compose_with_connectors
Mirrors the HybridComposition::compose from the apollo-composition crate.
expand_subgraphs
Apollo Federation allow subgraphs to specify partial schemas (i.e. “import” directives through @link). This function will update subgraph schemas with all missing federation definitions.
merge_subgraphs
post_merge_validations
pre_merge_validations
Perform validations that require information about all available subgraphs.
upgrade_subgraphs_if_necessary
Upgrade subgraphs if necessary and validate the result.
validate_satisfiability
validate_satisfiability_with_connectors
Mirroring HybridComposition in the apollo-composition crate.