pub enum EntityResolver {
Explicit,
Implicit,
TypeBatch,
TypeSingle,
}Expand description
Entity resolver type
A connector can be used as a potential entity resolver for a type, with extra validation rules based on the transport args and field position within a schema.
Variants
Explicit
The user defined a connector on a field that acts as an entity resolver
Implicit
The user defined a connector on a field of a type, so we need an entity resolver for that type
TypeBatch
The user defined a connector on the type directly and uses the $batch variable
TypeSingle
The user defined a connector on the type directly and uses the $this variable