pub struct HeaderValue(/* private fields */);Implementations
Sourceimpl HeaderValue
impl HeaderValue
pub fn parse_with_spec(s: &str, spec: ConnectSpec) -> Result<Self, Error>
Sourcepub fn interpolate(
&self,
vars: &IndexMap<String, Value>,
) -> Result<(HeaderValue, Vec<ApplyToError>), String>
pub fn interpolate( &self, vars: &IndexMap<String, Value>, ) -> Result<(HeaderValue, Vec<ApplyToError>), String>
Evaluate expressions in the header value.
Errors
Returns an error any expression can’t be evaluated, or evaluates to an unsupported type.
Methods from Deref<Target = StringTemplate>
Sourcepub fn interpolate(
&self,
vars: &IndexMap<String, Value>,
) -> Result<(String, Vec<ApplyToError>), Error>
pub fn interpolate( &self, vars: &IndexMap<String, Value>, ) -> Result<(String, Vec<ApplyToError>), Error>
Interpolate the expressions in the template into a basic string.
For URIs, use Self::interpolate_uri instead.
Sourcepub fn interpolate_uri(
&self,
vars: &IndexMap<String, Value>,
) -> Result<(Uri, Vec<ApplyToError>), Error>
pub fn interpolate_uri( &self, vars: &IndexMap<String, Value>, ) -> Result<(Uri, Vec<ApplyToError>), Error>
Interpolate the expression as a URI, percent-encoding parts as needed.