pub struct SelectionData {
pub source: String,
pub transformed: String,
pub result: Option<Value>,
}Expand description
JSONSelection Request / Response Data
Contains all needed info and responses from the application of a JSONSelection
Fields
source: StringThe original JSONSelection to resolve
transformed: StringA mapping of the original selection, taking into account renames and other transformations requested by the client
Refer to Self::source for the original, schema-supplied selection.
result: Option<Value>The result of applying the selection to JSON. An empty value here can potentially mean that errors were encountered.