Module errors

Module errors 

Structs

RuntimeError

Enums

Error
An error sending a connector request. This represents a problem with sending the request to the connector, rather than an error returned from the connector itself.