pub struct RuntimeError {
pub message: String,
pub coordinate: Option<String>,
pub subgraph_name: Option<String>,
pub path: String,
pub extensions: Map<ByteString, Value>,
/* private fields */
}Fields
message: Stringcoordinate: Option<String>subgraph_name: Option<String>path: Stringextensions: Map<ByteString, Value>Implementations
Sourceimpl RuntimeError
impl RuntimeError
pub fn new(message: impl Into<String>, response_key: &ResponseKey) -> Self
pub fn extensions(&self) -> Map<ByteString, Value>
pub fn extension<K, V>(self, key: K, value: V) -> Self
Sourcepub fn merge_extension<K, V>(self, key: K, value: V) -> Self
pub fn merge_extension<K, V>(self, key: K, value: V) -> Self
Like Self::extension, but if the existing value at key and the
incoming value are both objects, their fields are merged recursively
rather than the existing value being replaced wholesale. Used so a
user-supplied errors.extensions: "http: { myField: ... }" mapping
preserves the default http.status field set by map_error. See
the errors-as-data docs at
https://www.apollographql.com/docs/graphos/connectors/responses/error-handling
for the contract that defaults are retained alongside user fields.
pub fn with_code(self, code: impl Into<String>) -> Self
pub fn code(&self) -> &str
pub fn span_event_emitted(&self) -> bool
pub fn set_span_event_emitted(&mut self, value: bool)