pub enum ResponseKey {
RootField {
name: String,
selection: Arc<JSONSelection>,
inputs: RequestInputs,
},
Entity {
index: usize,
selection: Arc<JSONSelection>,
inputs: RequestInputs,
},
EntityField {
index: usize,
field_name: String,
typename: Option<Name>,
selection: Arc<JSONSelection>,
inputs: RequestInputs,
},
BatchEntity {
selection: Arc<JSONSelection>,
keys: Valid<FieldSet>,
inputs: RequestInputs,
},
}Variants
RootField
Entity
EntityField
Fields
typename: Option<Name>Is Some only if the output type is a concrete object type. If it’s an interface, it’s treated as an interface object and we can’t emit a __typename in the response.
selection: Arc<JSONSelection>inputs: RequestInputsBatchEntity
Implementations
Sourceimpl ResponseKey
impl ResponseKey
pub fn selection(&self) -> &JSONSelection
pub fn inputs(&self) -> &RequestInputs
Sourcepub fn path_string(&self) -> String
pub fn path_string(&self) -> String
Returns a serialized representation of the Path from apollo-router.
Intended to be parsed into a Path when converting a connectors
RuntimeError in the router’s graphql::Error.
This mimics the behavior of a GraphQL subgraph, including the _entities
field. When the path gets to FetchNode::response_at_path, it will be
amended and appended to a parent path to create the full path to the
field. For example:
- parent path:
["posts", @, "user"] - path from key:
["_entities", 0, "user", "profile"] - result:
["posts", 1, "user", "profile"]