Connector

Struct Connector 

pub struct Connector {
Show 15 fields pub id: ConnectId, pub transport: Option<HttpJsonTransport>, pub selection: JSONSelection, pub config: Option<CustomConfiguration>, pub max_requests: Option<usize>, pub entity_resolver: Option<EntityResolver>, pub spec: ConnectSpec, pub schema_subtypes_map: IndexMap<String, IndexSet<String>>, pub request_headers: HashSet<String>, pub response_headers: HashSet<String>, pub request_variable_keys: IndexMap<Namespace, IndexSet<String>>, pub response_variable_keys: IndexMap<Namespace, IndexSet<String>>, pub batch_settings: Option<ConnectBatchArguments>, pub error_settings: ConnectorErrorsSettings, pub label: Label,
}

Fields

id: ConnectIdtransport: Option<HttpJsonTransport>

HTTP transport configuration. None for mapping-only connectors (where http is omitted).

selection: JSONSelectionconfig: Option<CustomConfiguration>max_requests: Option<usize>entity_resolver: Option<EntityResolver>

The type of entity resolver to use for this connector

spec: ConnectSpec

Which version of the connect spec is this connector using?

schema_subtypes_map: IndexMap<String, IndexSet<String>>

All supertype-subtype(s) relationships from the source schema.

request_headers: HashSet<String>

The request headers referenced in the connectors request mapping

response_headers: HashSet<String>

The request or response headers referenced in the connectors response mapping

request_variable_keys: IndexMap<Namespace, IndexSet<String>>

Environment and context variable keys referenced in the connector

response_variable_keys: IndexMap<Namespace, IndexSet<String>>batch_settings: Option<ConnectBatchArguments>error_settings: ConnectorErrorsSettingslabel: Label

A label for use in debugging and logging. Includes ID, transport method, and path.

Implementations

Source

impl Connector

pub fn from_schema( schema: &Schema, subgraph_name: &str, ) -> Result<Vec<Self>, FederationError>

Get a map of connectors from an apollo_compiler::Schema.

Note: the function assumes that we’ve checked that the schema is valid before calling this function. We can’t take a Valid<Schema> or ValidFederationSchema because we use this code in validation, which occurs before we’ve augmented the schema with types from @link directives.

pub fn subtypes_map_from_schema( schema: &Schema, ) -> IndexMap<String, IndexSet<String>>

pub fn resolvable_key( &self, schema: &Schema, ) -> Result<Option<Valid<FieldSet>>, String>

Create a field set for a @key using $args, $this, or $batch variables.

pub fn source_config_key(&self) -> String

Create an identifier for this connector that can be used for configuration and service identification source_name will be None here when we are using a “sourceless” connector. In this situation, we’ll use the synthetic_name instead so that we have some kind of a unique identifier for this source.

pub fn name(&self) -> Name

Get the name of the @connect directive associated with this Connector instance.

The Name can be used to help locate the connector within a source file.

pub fn id(&self) -> String

Get the id`` of the @connect directive associated with this [Connector`] instance.

pub fn abstract_types(&self) -> IndexSet<String>

Get the set of abstract type names from the schema subtypes map