pub struct JSONSelection {
pub spec: ConnectSpec,
/* private fields */
}Fields
spec: ConnectSpecImplementations
Sourceimpl JSONSelection
impl JSONSelection
Sourceimpl JSONSelection
impl JSONSelection
pub fn spec(&self) -> ConnectSpec
pub fn named(sub: SubSelection) -> Self
pub fn path(path: PathSelection) -> Self
pub fn empty() -> Self
pub fn is_empty(&self) -> bool
pub fn parse(input: &str) -> Result<Self, JSONSelectionParseError>
pub fn parse_with_spec( input: &str, spec: ConnectSpec, ) -> Result<Self, JSONSelectionParseError>
pub fn variable_references( &self, ) -> impl Iterator<Item = VariableReference<Namespace>> + '_
Sourceimpl JSONSelection
impl JSONSelection
Sourcepub fn apply_selection_set(
&self,
abstract_types: &IndexSet<String>,
document: &ExecutableDocument,
selection_set: &SelectionSet,
required_keys: Option<&FieldSet>,
) -> Self
pub fn apply_selection_set( &self, abstract_types: &IndexSet<String>, document: &ExecutableDocument, selection_set: &SelectionSet, required_keys: Option<&FieldSet>, ) -> Self
Apply a selection set to create a new JSONSelection
Operations from the query planner will never contain key fields (because
it already has them from a previous fetch) but we might need those
fields for things like sorting entities in a batch. If the optional
required_keys is provided, we’ll merge those fields into the selection
set before applying it to the JSONSelection.