pub struct StringTemplate { /* private fields */ }Expand description
A parsed string template, containing a series of [Part]s.
Implementations
Sourceimpl StringTemplate
impl StringTemplate
pub fn parse_with_spec(input: &str, spec: ConnectSpec) -> Result<Self, Error>
Sourceimpl StringTemplate
impl StringTemplate
Sourcepub fn interpolate(
&self,
vars: &IndexMap<String, Value>,
) -> Result<(String, Vec<ApplyToError>), Error>
pub fn interpolate( &self, vars: &IndexMap<String, Value>, ) -> Result<(String, Vec<ApplyToError>), Error>
Interpolate the expressions in the template into a basic string.
For URIs, use Self::interpolate_uri instead.
Sourcepub fn interpolate_uri(
&self,
vars: &IndexMap<String, Value>,
) -> Result<(Uri, Vec<ApplyToError>), Error>
pub fn interpolate_uri( &self, vars: &IndexMap<String, Value>, ) -> Result<(Uri, Vec<ApplyToError>), Error>
Interpolate the expression as a URI, percent-encoding parts as needed.