Module error

Module error 

Structs

AggregateFederationError
ErrorCodeDefinition
ErrorCodeIter
An iterator over the variants of ErrorCode
ErrorCodeMetadata
InaccessibleCompositionLinks
Supergraph coordinates carried on @inaccessible API schema errors so composition can attach subgraph source locations (port of JS inaccessible_elements / inaccessible_referencers extensions and updateInaccessibleErrorsWithLinkToSubgraphs). Those locations are surfaced on CompositionError::MergeError as SubgraphLocation entries (Rust equivalent of JS withModifiedErrorNodes).
MultipleFederationErrors
SubgraphLocation
Modeled after SubgraphLocation defined in apollo_composition, so this struct can be converted to it.

Enums

CompositionError
ErrorCode
FederationError
SingleFederationError
UnsupportedFeatureKind

Traits

MultiTry
MultiTryAll

Type Aliases

Locations