pub struct LinksMetadata { /* private fields */ }Expand description
Metadata about all the applications of @link in a schema.
Implementations
Sourceimpl LinksMetadata
impl LinksMetadata
Sourcepub fn from_schema(
schema: &Schema,
) -> Result<Option<LinksMetadata>, FederationError>
pub fn from_schema( schema: &Schema, ) -> Result<Option<LinksMetadata>, FederationError>
Create @link metadata from a schema. Specifically it:
- Finds the bootstrapping @link directive and definition (and ensures there’s only one).
- Runs link spec validations against @link applications.
- Checks if imports are for known elements for @link applications with known specs.
- Collects metadata about @link applications.
It does not:
- Expand definitions for any linked specs (including the link spec itself).
- Require definitions to be expanded, other than for the bootstrapping @link directive.
- Run non-link spec validations against @link applications with known specs.
- Run validations to ensure no used shadowing imports (this must be done separately, after definitions have been expanded and referencers collected).
pub fn all_links(&self) -> impl ExactSizeIterator<Item = &Arc<Link>>
pub fn for_identity(&self, identity: &Identity) -> Option<Arc<Link>>
pub fn source_link_of_type(&self, type_name: &Name) -> Option<LinkedElement>
pub fn source_link_of_directive( &self, directive_name: &Name, ) -> Option<LinkedElement>