pub enum FetchDataRewrite {
ValueSetter(FetchDataValueSetter),
KeyRenamer(FetchDataKeyRenamer),
}Expand description
The type of rewrites currently supported on the input/output data of fetches.
A rewrite usually identifies some sub-part of the data and some action to perform on that sub-part.
Variants
ValueSetter(FetchDataValueSetter)
KeyRenamer(FetchDataKeyRenamer)