pub struct QueryPlanOptions<'a> {
pub override_conditions: Vec<String>,
pub check_for_cooperative_cancellation: Option<&'a dyn Fn() -> ControlFlow<()>>,
pub non_local_selections_limit_enabled: bool,
pub disabled_subgraph_names: IndexSet<String>,
}Fields
override_conditions: Vec<String>A set of labels which will be used during query planning to enable/disable edges with a matching label in their override condition. Edges with override conditions require their label to be present or absent from this set in order to be traversable. These labels enable the progressive @override feature.
check_for_cooperative_cancellation: Option<&'a dyn Fn() -> ControlFlow<()>>An optional function that will be called to check if the query plan should be cancelled.
Cooperative cancellation occurs when the original client has abandoned the query. When this happens, the query plan should be cancelled to free up resources.
This function should return ControlFlow::Break if the query plan should be cancelled.
Defaults to None.
non_local_selections_limit_enabled: boolImpose a limit on the number of non-local selections, which can be a performance hazard. On by default.
disabled_subgraph_names: IndexSet<String>Names of subgraphs that are disabled and should be avoided during
planning. If this is non-empty, query planner may error if it cannot
find a plan that doesn’t use the disabled subgraphs, specifically with
SingleFederationError::NoPlanFoundWithDisabledSubgraphs.