QueryPlannerConfig

Struct QueryPlannerConfig 

pub struct QueryPlannerConfig {
    pub generate_query_fragments: bool,
    pub subgraph_graphql_validation: bool,
    pub incremental_delivery: QueryPlanIncrementalDeliveryConfig,
    pub debug: QueryPlannerDebugConfig,
    pub type_conditioned_fetching: bool,
}

Fields

generate_query_fragments: bool

If enabled, the query planner will attempt to extract common subselections into named fragments. This can significantly reduce the size of the query sent to subgraphs.

Defaults to false.

subgraph_graphql_validation: bool

TODO: This option is not implemented, and the behaviour is always enabled. https://github.com/apollographql/router/pull/5871

Whether to run GraphQL validation against the extracted subgraph schemas. Recommended in non-production settings or when debugging.

Defaults to false.

incremental_delivery: QueryPlanIncrementalDeliveryConfigdebug: QueryPlannerDebugConfig

A sub-set of configurations that are meant for debugging or testing. All the configurations in this sub-set are provided without guarantees of stability (they may be dangerous) or continued support (they may be removed without warning).

type_conditioned_fetching: bool

Enables type conditioned fetching. This flag is a workaround, which may yield significant performance degradation when computing query plans, and increase query plan size.

If you aren’t aware of this flag, you probably don’t need it.