pub struct SerializableDocument { /* private fields */ }Expand description
Like Valid<ExecutableDocument>> but can be (de)serialized as a string in GraphQL syntax.
The relevant schema is required to parse from string but not available during deserialization, so this contains a dual (either or both) “string” or “parsed” representation. Accessing the latter is fallible, and requires an explicit initialization step to provide the schema.
Implementations
Sourceimpl SerializableDocument
impl SerializableDocument
pub fn from_string(serialized: impl Into<String>) -> Self
pub fn from_parsed(parsed: impl Into<Arc<Valid<ExecutableDocument>>>) -> Self
pub fn as_serialized(&self) -> &str
pub fn init_parsed( &mut self, subgraph_schema: &Valid<Schema>, ) -> Result<&Arc<Valid<ExecutableDocument>>, WithErrors<ExecutableDocument>>
pub fn as_parsed( &self, ) -> Result<&Arc<Valid<ExecutableDocument>>, SerializableDocumentNotInitialized>