pub struct DeferNode {
pub primary: PrimaryDeferBlock,
pub deferred: Vec<DeferredDeferBlock>,
}Expand description
A DeferNode corresponds to one or more @defer applications at the same level of “nestedness”
in the planned query.
It contains a “primary block” and a vector of “deferred blocks”. The “primary block” represents the part of the query that is not deferred (so the part of the query up until we reach the @defer(s) this handles), while each “deferred block” correspond to the deferred part of one of the @defer(s) handled by the node.
Note that DeferNodes are only generated if defer support is enabled for the query planner.
Also note that if said support is enabled, then DeferNodes are always generated if the query
has a @defer application, even if in some cases generated plan may not “truly” defer the
underlying fetches (i.e. in cases where deferred[*].node are all undefined). This currently
happens because some specific cases of defer cannot be handled, but could later also happen if
we implement more advanced server-side heuristics to decide if deferring is judicious or not.
This allows the executor of the plan to consistently send a defer-abiding multipart response to
the client.
Fields
primary: PrimaryDeferBlockThe “primary” part of a defer, that is the non-deferred part (though could be deferred itself for a nested defer).
deferred: Vec<DeferredDeferBlock>The “deferred” parts of the defer (note that it’s a vector). Each of those deferred elements will correspond to a different chunk of the response to the client (after the initial on-deferred one that is).