pub struct DeferredDeferBlock {
pub depends: Vec<DeferredDependency>,
pub label: Option<String>,
pub query_path: Vec<QueryPathElement>,
pub sub_selection: Option<String>,
pub node: Option<Box<PlanNode>>,
}Expand description
A deferred block of a DeferNode.
Fields
depends: Vec<DeferredDependency>References one or more fetch node(s) (by id) within DeferNode.primary.node. The plan of
this deferred part should not be started until all such fetches return.
label: Option<String>The optional defer label.
query_path: Vec<QueryPathElement>Path, in the query, to the @defer application this corresponds to. The sub_selection
starts at this query_path.
sub_selection: Option<String>The part of the original query that “selects” the data to send in the deferred response
(once the plan in node completes). Will be set unless node is a DeferNode itself.
node: Option<Box<PlanNode>>The plan to get all the data for this deferred block. Usually set, but can be None for a
@defer application where everything has been fetched in the “primary block” (i.e. when
this deferred block only exists to expose what should be send to the upstream client in a
deferred response), but without declaring additional fetches. This happens for @defer
applications that cannot be handled through the query planner and where the defer cannot be
passed through to the subgraph).