pub struct FetchDataKeyRenamer {
pub path: Vec<FetchDataPathElement>,
pub rename_key_to: Name,
}Expand description
A rewrite that renames the key at the provided path of the data it is applied to.
Fields
path: Vec<FetchDataPathElement>Path to the key that is renamed by this “rewrite”.
rename_key_to: NameThe key to rename to at path.