pub struct FetchDataValueSetter {
pub path: Vec<FetchDataPathElement>,
pub set_value_to: Value,
}Expand description
A rewrite that sets a value at the provided path of the data it is applied to.
Fields
path: Vec<FetchDataPathElement>Path to the value that is set by this “rewrite”.
set_value_to: ValueThe value to set at path. Note that the query planner currently only uses string values,
but that may change in the future.