pub struct FetchNode {
pub subgraph_name: Arc<str>,
pub id: Option<u64>,
pub variable_usages: Vec<Name>,
pub requires: Vec<Selection>,
pub operation_document: SerializableDocument,
pub operation_name: Option<Name>,
pub operation_kind: OperationType,
pub input_rewrites: Arc<Vec<Arc<FetchDataRewrite>>>,
pub output_rewrites: Vec<Arc<FetchDataRewrite>>,
pub context_rewrites: Vec<Arc<FetchDataRewrite>>,
}Fields
subgraph_name: Arc<str>id: Option<u64>Optional identifier for the fetch for defer support. All fetches of a given plan will be
guaranteed to have a unique id.
variable_usages: Vec<Name>requires: Vec<Selection>operation_document: SerializableDocumentoperation_name: Option<Name>operation_kind: OperationTypeinput_rewrites: Arc<Vec<Arc<FetchDataRewrite>>>Optionally describe a number of “rewrites” that query plan executors should apply to the data that is sent as the input of this fetch. Note that such rewrites should only impact the inputs of the fetch they are applied to (meaning that, as those inputs are collected from the current in-memory result, the rewrite should not impact said in-memory results, only what is sent in the fetch).
output_rewrites: Vec<Arc<FetchDataRewrite>>Similar to input_rewrites, but for optional “rewrites” to apply to the data that is
received from a fetch (and before it is applied to the current in-memory results).
context_rewrites: Vec<Arc<FetchDataRewrite>>Similar to the other kinds of rewrites. This is a mechanism to convert a contextual path into an argument to a resolver. Note value setters are currently unused here, but may be used in the future.