pub struct PrimaryDeferBlock {
pub sub_selection: Option<String>,
pub node: Option<Box<PlanNode>>,
}Expand description
The primary block of a DeferNode.
Fields
sub_selection: Option<String>The part of the original query that “selects” the data to send in that primary response
once the plan in node completes). Note that if the parent DeferNode is nested, then it
must come inside the DeferredNode in which it is nested, and in that case this
sub-selection will start at that parent DeferredNode.query_path. Note that this can be
None in the rare case that everything in the original query is deferred (which is not very
useful in practice, but not disallowed by the @defer spec at the moment).
node: Option<Box<PlanNode>>The plan to get all the data for the primary block. Same notes as for subselection: usually defined, but can be undefined in some corner cases where nothing is to be done in the primary block.