Module normalize_schema

Module normalize_schema 

Structs

Normalized
A marker wrapper that indicates the contained schema has been normalized via normalize_schema.

Functions

normalize_schema
For any two Schemas that are considered “equal”, normalizing them with this function will make it such that:
normalize_valid_schema
The same as normalize_schema, but for Valid Schemas. See that function’s doc comment for details.