Re-exports
pub use crate::supergraph::Merged;pub use crate::supergraph::Satisfiable;pub use crate::supergraph::Supergraph;
Structs
- Composition
Options - Options that configure composition. Mirrors the JS
CompositionOptionsinterface (seecomposition-js/src/compose.ts). Most fields are not yet ported — add them here as needed.
Functions
- compose
- Mirrors the JS
composefunction. - compose_
with_ connectors - Mirrors the
HybridComposition::composefrom the apollo-composition crate. - expand_
subgraphs - Apollo Federation allow subgraphs to specify partial schemas (i.e. “import” directives through
@link). This function will update subgraph schemas with all missing federation definitions. - merge_
subgraphs - post_
merge_ validations - pre_
merge_ validations - Perform validations that require information about all available subgraphs.
- upgrade_
subgraphs_ if_ necessary - Upgrade subgraphs if necessary and validate the result.
- validate_
satisfiability - validate_
satisfiability_ with_ connectors - Mirroring HybridComposition in the apollo-composition crate.