Structs
- Aggregate
Federation Error - Error
Code Definition - Error
Code Iter - An iterator over the variants of ErrorCode
- Error
Code Metadata - Inaccessible
Composition Links - Supergraph coordinates carried on
@inaccessibleAPI schema errors so composition can attach subgraph source locations (port of JSinaccessible_elements/inaccessible_referencersextensions andupdateInaccessibleErrorsWithLinkToSubgraphs). Those locations are surfaced onCompositionError::MergeErrorasSubgraphLocationentries (Rust equivalent of JSwithModifiedErrorNodes). - Multiple
Federation Errors - Subgraph
Location - Modeled after
SubgraphLocationdefined inapollo_composition, so this struct can be converted to it.