pub struct QueryPlannerDebugConfig {
pub max_evaluated_plans: NonZeroU32,
pub paths_limit: Option<u32>,
}Fields
max_evaluated_plans: NonZeroU32Query planning is an exploratory process. Depending on the specificities and feature used by subgraphs, there could exist may different theoretical valid (if not always efficient) plans for a given query, and at a high level, the query planner generates those possible choices, evaluates them, and return the best one. In some complex cases however, the number of theoretically possible plans can be very large, and to keep query planning time acceptable, the query planner caps the maximum number of plans it evaluates. This config allows to configure that cap. Note if planning a query hits that cap, then the planner will still always return a “correct” plan, but it may not return the optimal one, so this config can be considered a trade-off between the worst-time for query planning computation processing, and the risk of having non-optimal query plans (impacting query runtimes).
This value currently defaults to 10000, but this default is considered an implementation detail and is subject to change. We do not recommend setting this value unless it is to debug a specific issue (with unexpectedly slow query planning for instance). Remember that setting this value too low can negatively affect query runtime (due to the use of sub-optimal query plans).
paths_limit: Option<u32>Before creating query plans, for each path of fields in the query we compute all the possible options to traverse that path via the subgraphs. Multiple options can arise because fields in the path can be provided by multiple subgraphs, and abstract types (i.e. unions and interfaces) returned by fields sometimes require the query planner to traverse through each constituent object type. The number of options generated in this computation can grow large if the schema or query are sufficiently complex, and that will increase the time spent planning.
This config allows specifying a per-path limit to the number of options considered. If any path’s options exceeds this limit, query planning will abort and the operation will fail.
The default value is None, which specifies no limit.