Structs
- Normalized
- A marker wrapper that indicates the contained schema has been normalized via normalize_schema.
Functions
- normalize_
schema - For any two Schemas that are considered “equal”, normalizing them with this function will make it such that:
- normalize_
valid_ schema - The same as normalize_schema, but for Valid Schemas. See that function’s doc comment for details.